# readfilego

<br>[![Linux Build](https://img.shields.io/travis/danday74/readfilego/master.svg?label=linux)](https://travis-ci.org/danday74/readfilego)
[![Windows Build](https://img.shields.io/appveyor/ci/danday74/readfilego/master.svg?label=windows)](https://ci.appveyor.com/project/danday74/readfilego)
[![Coverage Status](https://coveralls.io/repos/github/danday74/readfilego/badge.svg)](https://coveralls.io/github/danday74/readfilego)
<br>[![npm](https://img.shields.io/npm/v/readfilego.svg)](https://www.npmjs.com/package/readfilego)
[![Dependencies Status](https://david-dm.org/danday74/readfilego/status.svg)](https://david-dm.org/danday74/readfilego)
[![npm](https://img.shields.io/npm/dm/readfilego.svg)](https://www.npmjs.com/package/readfilego)
[![node](https://img.shields.io/node/v/readfilego.svg)](https://www.npmjs.com/package/readfilego)

**"I just want to read my file and go"**



<br>

## Introduction

readfilego is a zero-dependency module that wraps [fs.readFileSync](https://nodejs.org/api/fs.html#fs_fs_readfilesync_path_options)

readfilego focuses on `file not found` behaviour. Default behaviour is to `console.warn` when you get `ENOENT: no such file or directory` instead of throwing an error but options give you full control.

readfilego removes the need for code scaffolding. One liners guaranteed.



<br>

## Usage

`npm install --save readfilego`

readfilego takes 2 arguments, the **path** to the file to read and optionally an [options object](#options-object)

An example to demonstrate usage:

```javascript 1.5
var readFileGo = require('readfile-go')
var options = {}
var contents = readFileGo(__dirname + '/path/to/my/file.md', options)
```



<br>

## Options object

Available options are:

[logFunc](#logfunc-function-) | message | silent | throw | [save](#save-boolean-) | [saveMessage](#savemessage-boolean-)

Default options are:

```javascript 1.5
var options = {
  encoding: 'utf8',       // See fs.readFileSync encoding option
  flag: 'r',              // See fs.readFileSync flag option
  logFunc: console.warn,  // Logger function to be called with the file not found message
  message: null,          // Message to be logged in place of - ENOENT: no such file or directory
  silent: false,          // Turn off logging?
  throw: false,           // Restore the normal file not found throw behaviour?
  save: false,            // Remember the -- encoding, flag, logFunc, silent, throw -- options for next time
  saveMessage: false      // Remember the -- message -- option for next time
}
```

Most options are self explanatory. Further explanation, where required, is given below.



<br>

#### **logFunc** (function) [![top](top.png)](#options-object)

Logger function to be called with the file not found message.

Defaults to `console.warn` but you can set `logFunc` to use your preferred logger function.

To illustrate, if you are using [loglevel](https://www.npmjs.com/package/loglevel) you could set `log.info` as your `logFunc`

```javascript 1.5
var readFileGo = require('readfile-go')
var log = require('loglevel')
var options = {logFunc: log.info}
var contents = readFileGo(__dirname + '/path/to/my/file.md', options)
```



<br>

#### **save** (boolean) [![top](top.png)](#options-object)

Its annoying to keep passing the same options every time.

readfilego, if instructed to do so, will remember previously used options for you.

When the `{save: true}` option is used in a call to `readFileGo` subsequent calls remember the -- encoding, flag, logFunc, silent, throw -- options.

```javascript 1.5
var readFileGo = require('readfile-go')
var contents1 = readFileGo(__dirname + '/path/to/my/file1.md', {silent: true, save: true})
var contents2 = readFileGo(__dirname + '/path/to/my/file2.md')
```

Here, the second call remembers that the silent option is on. `{silent: true}` is now the default.

Therefore, even if neither file exists, nothing will be logged for either call.



<br>

#### **saveMessage** (boolean) [![top](top.png)](#options-object)

Similar to the [save](#save-boolean-) option but subsequent calls only remember the -- message -- option.

Thereby allowing you to save a generic custom file not found message:

```javascript 1.5
var readFileGo = require('readfile-go')
var contents1 = readFileGo(__dirname + '/path/to/my/file1.md', {message: 'oopsie', saveMessage: true})
var contents2 = readFileGo(__dirname + '/path/to/my/file2.md')
```

After saving a message, if you wish to later restore the normal file not found message `ENOENT: no such file or directory` simply set `{message: null, saveMessage: true}`



<br>

## Author says

I would like to share these words of Jesus, who is precious to me, with you:

> The thief comes only to steal and kill and destroy. I came that they may have life and have it abundantly. [John 10:10 ESV](https://www.biblegateway.com/passage/?search=John+10%3A10&version=ESV)

Jesus is a friend and not an enemy to all those who would welcome Him :)



<br><br><br><br><br>
