'use strict'

var DEFAULTS = require('./defaultOptions')
var imp = require('../../test/_js/testImports')
var normaliseOptions = require('./index')

describe('normaliseOptions', function() {

  var actual, expected

  beforeEach(function() {
    actual = undefined
    expected = Object.assign({}, DEFAULTS)
  })

  it('options is undefined', function() {
    actual = normaliseOptions()
    imp.expect(actual).to.eql(expected)
  })

  it('options is not an object', function() {
    actual = normaliseOptions(9)
    imp.expect(actual).to.eql(expected)
  })

  it('options is an empty object', function() {
    actual = normaliseOptions({})
    imp.expect(actual).to.eql(expected)
  })

  it('encoding is a string', function() {
    expected.encoding = 'woteva'
    actual = normaliseOptions({encoding: ' woteva '})
    imp.expect(actual).to.eql(expected)
  })

  it('encoding is null', function() {
    expected.encoding = null
    actual = normaliseOptions({encoding: null})
    imp.expect(actual).to.eql(expected)
  })

  it('encoding is not a string', function() {
    actual = normaliseOptions({encoding: 9})
    imp.expect(actual).to.eql(expected)
  })

  it('flag is a string', function() {
    expected.flag = 'woteva'
    actual = normaliseOptions({flag: ' woteva '})
    imp.expect(actual).to.eql(expected)
  })

  it('flag is not a string', function() {
    actual = normaliseOptions({flag: 9})
    imp.expect(actual).to.eql(expected)
  })

  it('logFunc is a function', function() {

    function func() {
    }

    expected.logFunc = func
    actual = normaliseOptions({logFunc: func})
    imp.expect(actual).to.eql(expected)
  })

  it('logFunc is not a function', function() {
    actual = normaliseOptions({logFunc: 9})
    imp.expect(actual).to.eql(expected)
  })

  it('message is a string', function() {
    expected.message = 'woteva'
    actual = normaliseOptions({message: ' woteva '})
    imp.expect(actual).to.eql(expected)
  })

  it('message is null', function() {
    actual = normaliseOptions({message: null})
    imp.expect(actual).to.eql(expected)
  })

  it('message is not a string', function() {
    actual = normaliseOptions({message: 9})
    imp.expect(actual).to.eql(expected)
  })

  it('silent is a boolean', function() {
    expected.silent = true
    actual = normaliseOptions({silent: true})
    imp.expect(actual).to.eql(expected)
  })

  it('silent is not a boolean', function() {
    actual = normaliseOptions({silent: 'false'})
    imp.expect(actual).to.eql(expected)
  })

  it('throw is a boolean', function() {
    actual = normaliseOptions({throw: false})
    imp.expect(actual).to.eql(expected)
  })

  it('throw is not a boolean', function() {
    expected.throw = true
    actual = normaliseOptions({throw: 9})
    imp.expect(actual).to.eql(expected)
  })

  it('save', function() {
    var SAVE = true
    var THROW = true
    imp.expect(DEFAULTS.save).to.equal(false)
    imp.expect(DEFAULTS.throw).to.equal(false)
    expected.save = SAVE
    expected.throw = THROW
    actual = normaliseOptions({save: SAVE, throw: THROW})
    imp.expect(actual).to.eql(expected)
    imp.expect(DEFAULTS.save).to.equal(false)
    imp.expect(DEFAULTS.throw).to.equal(THROW)
  })

  it('saveMessage', function() {
    var SAVE = true
    var MESSAGE = 'herro'
    imp.expect(DEFAULTS.saveMessage).to.equal(false)
    imp.expect(DEFAULTS.message).to.equal(null)
    expected.saveMessage = SAVE
    expected.message = MESSAGE
    actual = normaliseOptions({saveMessage: SAVE, message: MESSAGE})
    imp.expect(actual).to.eql(expected)
    imp.expect(DEFAULTS.saveMessage).to.equal(false)
    imp.expect(DEFAULTS.message).to.equal(MESSAGE)
  })
})
