'use strict'

var imp = require('../_js/testImports')

describe('examples', function() {

  var DEFAULTS, sandbox

  before(function() {
    imp.logger.setLevel('silent')
  })

  beforeEach(function() {
    delete require.cache[require.resolve('../../js/normaliseOptions/defaultOptions')]
    DEFAULTS = require('../../js/normaliseOptions/defaultOptions')
    sandbox = imp.sinon.sandbox.create()
    sandbox.spy(imp.logger, 'info')
    sandbox.stub(DEFAULTS, 'logFunc')
  })

  afterEach(function() {
    sandbox.restore()
  })

  describe('usage', function() {

    it('success', function() {
      var readFileGo = require('../../index')
      var options = {}
      var contents = readFileGo(__dirname + '/path/to/my/file.md', options)

      imp.expect(contents).to.equal('woo hoo\n')
      imp.expect(DEFAULTS.logFunc).to.have.not.been.called
    })

    it('failure', function() {
      var readFileGo = require('../../index')
      var options = {}
      var contents = readFileGo(__dirname + '/paxxxxxth/to/my/file.md', options)

      imp.expect(contents).to.be.undefined
      imp.expect(DEFAULTS.logFunc).to.have.been.calledWithMatch(/ENOENT/)
    })
  })

  describe('logFunc', function() {

    it('success', function() {
      var readFileGo = require('../../index')
      var log = require('loglevel')
      var options = {logFunc: log.info}
      var contents = readFileGo(__dirname + '/path/to/my/file.md', options)

      imp.expect(contents).to.equal('woo hoo\n')
      imp.expect(DEFAULTS.logFunc).to.have.not.been.called
      imp.expect(log.info).to.have.not.been.called
    })

    it('failure', function() {
      var readFileGo = require('../../index')
      var log = require('loglevel')
      var options = {logFunc: log.info}
      var contents = readFileGo(__dirname + '/paxxxxxth/to/my/file.md', options)

      imp.expect(contents).to.be.undefined
      imp.expect(DEFAULTS.logFunc).to.have.not.been.called
      imp.expect(log.info).to.have.been.calledWithMatch(/ENOENT/)
    })
  })

  describe('save', function() {

    it('success', function() {
      var readFileGo = require('../../index')
      var contents1 = readFileGo(__dirname + '/path/to/my/file1.md', {silent: true, save: true})
      var contents2 = readFileGo(__dirname + '/path/to/my/file2.md')

      imp.expect(contents1).to.equal('woo hoo 1\n')
      imp.expect(contents2).to.equal('woo hoo 2\n')
      imp.expect(DEFAULTS.logFunc).to.have.not.been.called
    })

    it('failure', function() {
      var readFileGo = require('../../index')
      var contents1 = readFileGo(__dirname + '/paxxxxxth/to/my/file1.md', {silent: true, save: true})
      var contents2 = readFileGo(__dirname + '/paxxxxxth/to/my/file2.md')

      imp.expect(contents1).to.be.undefined
      imp.expect(contents2).to.be.undefined
      imp.expect(DEFAULTS.logFunc).to.have.not.been.called
    })
  })

  describe('saveMessage', function() {

    it('success', function() {
      var readFileGo = require('../../index')
      var contents1 = readFileGo(__dirname + '/path/to/my/file1.md', {message: 'oopsie', saveMessage: true})
      var contents2 = readFileGo(__dirname + '/path/to/my/file2.md')

      imp.expect(contents1).to.equal('woo hoo 1\n')
      imp.expect(contents2).to.equal('woo hoo 2\n')
      imp.expect(DEFAULTS.logFunc).to.have.not.been.called
    })

    it('failure', function() {
      var readFileGo = require('../../index')
      var contents1 = readFileGo(__dirname + '/paxxxxxth/to/my/file1.md', {message: 'oopsie', saveMessage: true})
      var contents2 = readFileGo(__dirname + '/paxxxxxth/to/my/file2.md')

      imp.expect(contents1).to.be.undefined
      imp.expect(contents2).to.be.undefined
      imp.expect(DEFAULTS.logFunc).to.have.been.calledTwice
      imp.expect(DEFAULTS.logFunc.firstCall).to.have.been.calledWith('oopsie ' + __dirname + '/paxxxxxth/to/my/file1.md')
      imp.expect(DEFAULTS.logFunc.secondCall).to.have.been.calledWith('oopsie ' + __dirname + '/paxxxxxth/to/my/file2.md')
    })

    it('restore', function() {
      var readFileGo = require('../../index')
      var contents1 = readFileGo(__dirname + '/paxxxxxth/to/my/file1.md', {message: 'oopsie', saveMessage: true})
      var contents2 = readFileGo(__dirname + '/paxxxxxth/to/my/file2.md')
      var contents3 = readFileGo(__dirname + '/paxxxxxth/to/my/file1.md', {message: null, saveMessage: true})
      var contents4 = readFileGo(__dirname + '/paxxxxxth/to/my/file2.md')

      imp.expect(contents1).to.be.undefined
      imp.expect(contents2).to.be.undefined
      imp.expect(contents3).to.be.undefined
      imp.expect(contents4).to.be.undefined
      imp.expect(DEFAULTS.logFunc).to.have.callCount(4)
      imp.expect(DEFAULTS.logFunc.getCall(0)).to.have.been.calledWith('oopsie ' + __dirname + '/paxxxxxth/to/my/file1.md')
      imp.expect(DEFAULTS.logFunc.getCall(1)).to.have.been.calledWith('oopsie ' + __dirname + '/paxxxxxth/to/my/file2.md')
      imp.expect(DEFAULTS.logFunc.getCall(2)).to.have.been.calledWithMatch(/ENOENT/)
      imp.expect(DEFAULTS.logFunc.getCall(3)).to.have.been.calledWithMatch(/ENOENT/)
    })
  })
})
